==> it%2B%2B-3.8.0_1.tbz: include/it++/comm/hammcode.h <==
/*---------------------------------------------------------------------------*
 *                                   IT++			             *
 *---------------------------------------------------------------------------*
 * Copyright (c) 1995-2004 by Tony Ottosson, Thomas Eriksson, Pl Frenger,   *
 * Tobias Ringstrm, and Jonas Samuelsson.                                   *
 *                                                                           *
 * Permission to use, copy, modify, and distribute this software and its     *
 * documentation under the terms of the GNU General Public License is hereby *
 * granted. No representations are made about the suitability of this        *
 * software for any purpose. It is provided "as is" without expressed or     *
 * implied warranty. See the GNU General Public License for more details.    *
 *---------------------------------------------------------------------------*/

/*! 
  \file 
  \brief Definitions of a Hamming code class
  \author Tony Ottosson

  1.6

  2004/08/17 09:27:23
*/

#ifndef __hamming_h
#define __hamming_h

#include "base/vec.h"
#include "base/mat.h"

namespace itpp {

  /*! 
    \ingroup fec
    \brief Binary Hamming codes
  */
  class Hamming_Code {
  public:
    //! Constructor for \c hamming(n,k). n = pow(2,m)-1 and k = pow(2,m)-m-1.
    Hamming_Code(short m);
    //! Hamming encoder. Will truncate some bits if not \a length = \c integer * \a k.
    void encode(const bvec &uncoded_bits, bvec &coded_bits);
    //! Hamming encoder. Will truncate some bits if not \a length = \c integer * \a k.
    bvec encode(const bvec &uncoded_bits);
    //! Hamming decoder. Will truncate some bits if not \a length = \c integer * \a n.
    void decode(const bvec &coded_bits, bvec &decoded_bits);
    //! Hamming decoder. Will truncate some bits if not \a length = \c integer * \a n.
    bvec decode(const bvec &coded_bits);
    //! Gets the code length \a n.
    short get_n() { return n; };
    //! Gets the number of information bits per code word, \a k.
    short get_k() { return k; };
    //! Gets the parity check matrix for the code.
    bmat get_H() { return H; };
    //! Gets the generator matrix for the code.
    bmat get_G() { return G; };
  private:
    short n, k; 
    bmat H, G;
    void generate_H(void);
    void generate_G(void);
  };

} //namespace itpp

#endif // __hamming_h

==> it%2B%2B-3.8.1.tbz: include/it++/comm/hammcode.h <==
/*---------------------------------------------------------------------------*
 *                                   IT++			             *
 *---------------------------------------------------------------------------*
 * Copyright (c) 1995-2005 by Tony Ottosson, Thomas Eriksson, Pl Frenger,   *
 * Tobias Ringstrm, and Jonas Samuelsson.                                   *
 *                                                                           *
 * Permission to use, copy, modify, and distribute this software and its     *
 * documentation under the terms of the GNU General Public License is hereby *
 * granted. No representations are made about the suitability of this        *
 * software for any purpose. It is provided "as is" without expressed or     *
 * implied warranty. See the GNU General Public License for more details.    *
 *---------------------------------------------------------------------------*/

/*! 
  \file 
  \brief Definitions of a Hamming code class
  \author Tony Ottosson

  1.8

  2005/05/27 17:26:22
*/

#ifndef __hamming_h
#define __hamming_h

#include "base/vec.h"
#include "base/mat.h"
#include "comm/channel_code.h"

namespace itpp {

  /*! 
    \ingroup fec
    \brief Binary Hamming codes
  */
  class Hamming_Code : public Channel_Code {
  public:
    //! Constructor for \c hamming(n,k). n = pow(2,m)-1 and k = pow(2,m)-m-1.
    Hamming_Code(short m);

    //! Destructor
    virtual ~Hamming_Code(){ }

    //! Hamming encoder. Will truncate some bits if not \a length = \c integer * \a k.
    virtual void encode(const bvec &uncoded_bits, bvec &coded_bits);
    //! Hamming encoder. Will truncate some bits if not \a length = \c integer * \a k.
    virtual bvec encode(const bvec &uncoded_bits);

    //! Hamming decoder. Will truncate some bits if not \a length = \c integer * \a n.
    virtual void decode(const bvec &coded_bits, bvec &decoded_bits);
    //! Hamming decoder. Will truncate some bits if not \a length = \c integer * \a n.
    virtual bvec decode(const bvec &coded_bits);

    // Soft-decision decoding is not implemented
    virtual void decode(const vec &received_signal, bvec &output);
    virtual bvec decode(const vec &received_signal);

    //! Get the code rate
    virtual double get_rate() { return (double)k/(double)n; };

    //! Gets the code length \a n.
    short get_n() { return n; };
    //! Gets the number of information bits per code word, \a k.
    short get_k() { return k; };
    //! Gets the parity check matrix for the code.
    bmat get_H() { return H; };
    //! Gets the generator matrix for the code.
    bmat get_G() { return G; };
  private:
    short n, k; 
    bmat H, G;
    void generate_H(void);
    void generate_G(void);
  };

} //namespace itpp

#endif // __hamming_h
